@@ -705,7 +705,8 @@ G_Run()
                          * SDL_AddTimer(KEY_ESCAPE_TIMEOUT,
                          * (SDL_NewTimerCallback)app_escape_timeout, (void
                          * *)0); } } */
-                        if( ev.key.keysym.sym == SDLK_q &&
+#if 0
+			if( ev.key.keysym.sym == SDLK_q &&
                             ev.key.keysym.mod | ( KMOD_RCTRL & KMOD_LCTRL ) ) {
                         	printf( "Close whole game\n" );
                         	/* Add code here to send message to startup */
@@ -717,7 +718,8 @@ G_Run()
                             gm.m_warp = 1;    
                             break;                    	
                         }
-                            
+#endif
+                        
                         if ((ev.key.keysym.sym == SDLK_ESCAPE)
                             || (ev.key.keysym.sym == SDLK_F6)
                             || (ev.key.keysym.sym == SDLK_F5))
@@ -751,13 +753,6 @@ G_Run()
 
                                 exit_callback(0);
                                 break;
-                            case SDLK_p:
-                                G_Ps();
-                                break;
-                            case SDLK_r:
-                                if (G_CfmRst())
-                                    restart = 1;
-                                break;
                             case SDLK_RETURN:
                                 if (gm.m_sel && !gm.m_mv)
                                     Mr_Rel( /* ev.button.x, ev.button.y */ );
