@@ -38,14 +38,25 @@
 #include <glib.h>
 #include <osso-log.h>
 #include <libosso.h>
+#include <signal.h>
 
 /* Ugly global. */
 HgwContext *sapp_context = NULL;
 osso_context_t *osso;
 int home_pressed = 0;
 
+static void sig_handler(int signum);
 void osso_hw_state(osso_hw_state_t * state, gpointer data);
 
+static void
+sig_handler(int signum)
+{
+    if (signum == SIGTERM)
+    {
+        exit_callback(0);
+    }
+}
+
 void
 osso_hw_state(osso_hw_state_t * state, gpointer data)
 {
@@ -109,6 +120,9 @@ main(int argc, char *argv[])
     if (dFile)
         fclose(dFile);
 
+    // if startup kills us, we want to save the state
+    signal(SIGTERM, sig_handler);
+
     hw_state.shutdown_ind = FALSE;
     hw_state.save_unsaved_data_ind = FALSE;
     hw_state.memory_low_ind = FALSE;
